.. ANDES documentation master file, created by
   sphinx-quickstart on Thu Jun 21 11:11:34 2018.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

##################
ANDES User's Guide
##################

ANDES is a Python-based power system simulation tool for research. It
supports power flow calculation, time domain simulation, and full eigenvalue
analysis for transmission networks. ANDES is currently under active development.

.. toctree::
   :caption: ANDES Tutorial
   :maxdepth: 2

   copyright.rst
   intro.rst
   install.rst
   walkthrough.rst
   formats.rst
   cases.rst
   modeling.rst
   release-history.rst

.. toctree::
   :caption: ANDES Package References
   :maxdepth: 2

   modules.rst


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`


Acknowledgement
===============
This work was supported in part by the Engineering Research Center Program of
the National Science Foundation and the Department of Energy under NSF Award
Number EEC-1041877 and the CURENT Industry Partnership Program.
